========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/neutron-lib.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

===============================
neutron-lib
===============================

Neutron shared routines and utilities

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/neutron-lib
* Source: http://git.openstack.org/cgit/openstack/neutron-lib
* Bugs: http://bugs.launchpad.net/neutron

Features
--------

* TODO
